NoneBot.drivers.quart 模块 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

# # NoneBot.drivers.quart 模块

## # Quart 驱动适配

后端使用方法请参考: Quart 文档
(opens new window)

## # class `Driver`

基类：`nonebot.drivers.Driver`

Quart 驱动框架

- 上报地址

  - `/{adapter name}/http`: HTTP POST 上报

  - `/{adapter name}/ws`: WebSocket 上报

### # property `type`

驱动名称: `quart`

### # property `server_app`

`Quart` 对象

### # property `asgi`

`Quart` 对象

### # property `logger`

fastapi 使用的 logger

### # `on_startup(func)`

参考文档: Startup and Shutdown
(opens new window)

### # `on_shutdown(func)`

参考文档: Startup and Shutdown
(opens new window)

### # `run(host=None, port=None, *, app=None, **kwargs)`

使用 `uvicorn` 启动 Quart

Contents

- Quart 驱动适配
- class Driver
  - property type
  - property server_app
  - property asgi
  - property logger
  - on_startup(func)
  - on_shutdown(func)
  - run(host=None, port=None, *, app=None, **kwargs)